@@ -293,7 +293,7 @@ class Kanata(BaseDispatcher):
         return result
 
     @lru_cache(None)
-    def catch_argument_names(self) -> List[str]:
+    async def catch_argument_names(self) -> List[str]:
         return [i.name for i in self.signature_list if isinstance(i, PatternReceiver)]
 
     async def beforeDispatch(self, interface: DispatcherInterface):
@@ -334,7 +334,7 @@ class Kanata(BaseDispatcher):
 
     async def afterDispatch(
         self,
-        interface: "IDispatcherInterface",
+        interface: "DispatcherInterface",
         exception: Optional[Exception] = None,
         tb: Optional[TracebackType] = None,
     ):
